"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transactionalReadAsync = void 0;
const retryAsync_1 = require("./retryAsync");
/**
 * Similar to transactionalReadWrite and transactionalWrite but only allows reads.
 */
function transactionalReadAsync(retries = 5) {
    return function (fn) {
        return async function (dbOrTx, ...args) {
            if (!("transact" in dbOrTx))
                return fn(dbOrTx, ...args);
            return await (0, retryAsync_1.retryAsync)(retries, async () => {
                const tx = dbOrTx.transact();
                const result = await fn(tx, ...args);
                await tx.commit();
                return result;
            });
        };
    };
}
exports.transactionalReadAsync = transactionalReadAsync;
//# sourceMappingURL=../../../src/database/async/transactionalReadAsync.js.map